@@ -434,6 +434,8 @@ class Snaplib:
 
         
         def predict(X__train, y__train, X__pred, all_algorithms, values_counted=None):
+            print(type(y__train))
+            print(pd.Series(y__train).value_counts())
             if len(pd.Series(y__train).value_counts()) == 1:
                 all_algorithms = [all_algorithms[0]]
                 
